@@ -1,6 +1,5 @@
 #include "plot.h"
 #include <qwt_scale_engine.h>
-#include <qwt_plot_curve.h>
 #include <qwt_plot_grid.h>
 #include <qwt_symbol.h>
 
@@ -14,6 +13,7 @@ Plot::Plot(QWidget *parent) :
     initializeCanvas();
     initializeCurve();
     initializeMarkers();
+    initializePicker();
     setAutoReplot(true);
 }
 
@@ -27,6 +27,7 @@ Plot::Plot(QwtText title, QWidget *parent) :
     initializeCanvas();
     initializeCurve();
     initializeMarkers();
+    initializePicker();
     setAutoReplot(true);
 }
 
@@ -34,6 +35,10 @@ Plot::~Plot()
 {
     curve->setSamples(QVector<QPointF>());
     replot();
+    delete picker;
+    delete marker3;
+    delete markerP;
+    delete curve;
 }
 
 void Plot::plot(const QList<double> x, QList<double> y)
@@ -97,6 +102,13 @@ void Plot::initializeMarkers()
 
 }
 
+void Plot::initializePicker()
+{
+    picker = new QwtPlotPicker(this->canvas());
+    picker->setRubberBand(QwtPlotPicker::CrossRubberBand);
+    picker->setTrackerMode(QwtPlotPicker::AlwaysOn);
+}
+
 double Plot::getXmax() const
 {
     return xmax;
@@ -125,7 +137,7 @@ void Plot::initializeCanvas() {
 
 void Plot::initializeScales() {
     QwtText XAxisLabel;
-    XAxisLabel.setText("Frequency [Hz]");
+    XAxisLabel.setText(tr("Frequency [Hz]"));
     setAxisTitle(QwtPlot::xBottom, XAxisLabel);
     setAxisMaxMajor(QwtPlot::xBottom, 3);
     setAxisMaxMinor(QwtPlot::xBottom, 10);
@@ -137,7 +149,7 @@ void Plot::initializeScales() {
     setAxisScale(QwtPlot::xBottom, xmin, xmax);
 
     QwtText YAxisLabel;
-    YAxisLabel.setText("Sound pressure [dB]");
+    YAxisLabel.setText(tr("Sound pressure [dB]"));
     setAxisTitle(QwtPlot::yLeft, YAxisLabel);
     setAxisMaxMajor(QwtPlot::yLeft, 5);
     setAxisMaxMinor(QwtPlot::yLeft, 10);
@@ -146,8 +158,7 @@ void Plot::initializeScales() {
 
 void Plot::showPeak(double x, double y)
 {
-    QString label;
-    label.sprintf("Peak: %d dB", (int)round(y));
+    QString label = QString(tr("Peak: %1 dB")).arg((int)round(y));
 
     QwtText text(label);
     text.setColor(Qt::red);
@@ -158,8 +169,7 @@ void Plot::showPeak(double x, double y)
 
 void Plot::show3dB(double x, double y)
 {
-    QString label;
-    label.sprintf("%d dB at %d Hz", (int)round(y), (int)x);
+    QString label = QString(tr("%1 dB at %2 Hz")).arg((int)round(y)).arg((int)x);
 
     QwtText text(label);
     text.setColor(Qt::blue);
