@@ -4,6 +4,7 @@
 #include <qwt_plot.h>
 #include <qwt_plot_curve.h>
 #include <qwt_plot_marker.h>
+#include <qwt_plot_picker.h>
 
 class Plot : public QwtPlot
 {
@@ -26,13 +27,14 @@ protected:
     void initializeCanvas();
     void initializeCurve();
     void initializeMarkers();
-
+    void initializePicker();
 private:
     QwtPlotCurve *curve;
     double xmin;
     double xmax;
     QwtPlotMarker *markerP;
     QwtPlotMarker *marker3;
+    QwtPlotPicker *picker;
 };
 
 #endif // PLOT_H
